<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:s="http://software.in2p3.fr/cmdb/services.xsd"
                xmlns:g="http://graphml.graphdrawing.org/xmlns"
                xmlns="http://www.w3.org/1999/xhtml">
    <xsl:output method="html"/>
    <xsl:param name="date"/>
    <xsl:template match="/s:dependencies">
        <html>
            <head>
                <style type="text/css">
                    .essential    { color: red; }
                    .important    { color: orange; }
                    .minor        { color: green; }
                </style>
                <!-- http://netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap.min.css -->
                <link href="bootstrap.min.css" rel="stylesheet" type="text/css" id="bootstrap.css"/>
            </head>
            <body>
                <xml id="graphml" style="display: none">
                    <g:graphml>
                        <g:key for="graph" id="rankdir">
                            <g:default>LR</g:default>
                        </g:key>
                        <g:graph id="G" edgedefault="directed">
                            <xsl:apply-templates select="s:services" mode="graphml"/>
                        </g:graph>
                    </g:graphml>
                </xml>
                <div class="container">
                    <div class="row">
                        <div class="pull-left well">
                            <u>Index</u>
                            <ul><li>
                                <a href="#A">A</a><a href="#B">B</a><a href="#C">C</a><a href="#D">D</a><a href="#E">E</a>
                                <a href="#F">F</a><a href="#G">G</a><a href="#H">H</a><a href="#I">I</a><a href="#J">J</a>
                                <a href="#K">K</a><a href="#L">L</a><a href="#M">M</a><a href="#N">N</a><a href="#O">O</a>
                                <a href="#P">P</a><a href="#Q">Q</a><a href="#R">R</a><a href="#S">S</a><a href="#T">T</a>
                                <a href="#U">U</a><a href="#V">V</a><a href="#W">W</a><a href="#X">X</a><a href="#Y">Y</a>
                                <a href="#Z">Z</a>
                            </li><li>
                                <a href="#Graph">Go to graph</a>
                            </li></ul>
                        </div>
                        <div class="pull-right well">
                            <u>Legende</u>
                            <ul>
                                <li class="essential">ESSENTIEL</li>
                                <li class="important">IMPORTANT</li>
                                <li class="minor">MINEUR</li>
                            </ul>
                        </div>
                        <div align="center"><xsl:value-of select="$date"/></div>
                    </div>
                    <table class="table">
                        <thead>
                            <tr>
                                <th>Experts</th>
                                <th>Service</th>
                                <th>Dependence</th>
                                <th>Remarque</th>
                            </tr>
                        </thead>
                        <tbody>
                            <xsl:apply-templates select="s:services/s:service[not(s:instance)] | s:services/s:service/s:instance">
                                <xsl:sort select="@name"/>
                            </xsl:apply-templates>
                        </tbody>
                    </table>

                    <div id="Graph"/>
                    <!-- http://git.in2p3.fr/public/lavoisier/plain/lavoisier-gui-admin/resources/js -->
                    <script src="viz.js">//</script>
                    <script src="viz-graphml.js">//</script>
                </div>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="s:service[not(s:depends)] | s:instance[not(s:depends|following-sibling::s:depends)]">
        <tr>
            <td>
                <div id="{substring(@name,1,1)}"/>
                <xsl:value-of select="ancestor::s:services/@experts"/>
            </td>
            <td>
                <div id="{translate(@name,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')}"/>
                <xsl:choose>
                    <xsl:when test="ancestor-or-self::s:service/@wiki=''">
                        <xsl:value-of select="@name"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:variable name="wiki">
                            <xsl:apply-templates select="ancestor-or-self::s:service" mode="wiki"/>
                        </xsl:variable>
                        <a href="{$wiki}"><xsl:value-of select="@name"/></a>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td/>
            <td/>
        </tr>
    </xsl:template>
    <xsl:template match="s:service">
        <xsl:apply-templates select="s:depends">
            <xsl:with-param name="source" select="@name"/>
        </xsl:apply-templates>
    </xsl:template>
    <xsl:template match="s:instance">
        <xsl:apply-templates select="s:depends | parent::s:service/s:depends">
            <xsl:with-param name="source" select="@name"/>
        </xsl:apply-templates>
    </xsl:template>
    <xsl:template match="s:depends">
        <xsl:param name="source"/>
        <tr>
            <xsl:if test="position() = 1">
                <td rowspan="{count(ancestor::s:service/s:depends | parent::s:instance/s:depends)}">
                    <div id="{substring($source,1,1)}"/>
                    <xsl:value-of select="ancestor::s:services/@experts"/>
                </td>
                <td rowspan="{count(ancestor::s:service/s:depends | parent::s:instance/s:depends)}">
                    <div id="{translate($source,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')}"/>
                    <xsl:choose>
                        <xsl:when test="$source/ancestor-or-self::s:service/@wiki=''">
                            <xsl:value-of select="$source"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:variable name="wiki">
                                <xsl:apply-templates select="$source/ancestor-or-self::s:service" mode="wiki"/>
                            </xsl:variable>
                            <a href="{$wiki}"><xsl:value-of select="$source"/></a>
                        </xsl:otherwise>
                    </xsl:choose>
                </td>
            </xsl:if>
            <td>
                <a href="#{translate(@on,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')}" class="{@criticality}"><xsl:value-of select="@on"/></a>
            </td>
            <td>
                <xsl:value-of select="text()"/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="s:service" mode="wiki">
        <xsl:text>https://doc.cc.in2p3.fr/intranet:astreinte:docservices:consignes:</xsl:text>
        <xsl:choose>
            <xsl:when test="@wiki">
                <xsl:value-of select="@wiki"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="translate(@name,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/></xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="s:services" mode="graphml">
        <xsl:apply-templates select="s:service[not(s:instance)] | s:service/s:instance" mode="graphml"/>
    </xsl:template>
    <xsl:template match="s:service" mode="graphml">
        <g:node id="{@name}"/>
        <xsl:apply-templates select="s:depends" mode="graphml">
            <xsl:with-param name="source" select="@name"/>
        </xsl:apply-templates>
    </xsl:template>
    <xsl:template match="s:instance" mode="graphml">
        <g:node id="{@name}"/>
        <xsl:apply-templates select="s:depends | parent::s:service/s:depends" mode="graphml">
            <xsl:with-param name="source" select="@name"/>
        </xsl:apply-templates>
    </xsl:template>
    <xsl:template match="s:depends" mode="graphml">
        <xsl:param name="source"/>
        <g:edge source="{@on}" target="{$source}">
            <g:data key="color">
                <xsl:choose>
                    <xsl:when test="@criticality='essential'">red</xsl:when>
                    <xsl:when test="@criticality='important'">orange</xsl:when>
                    <xsl:when test="@criticality='minor'">green</xsl:when>
                </xsl:choose>
            </g:data>
        </g:edge>
    </xsl:template>
</xsl:stylesheet>